@@ -306,7 +306,7 @@ class API:  # pylint: disable=too-many-instance-attributes
         await self.async_update_subscription_data()
 
         for sid, subscription in self.subscription_data.items():
-            if not subscription["activated"] != 0:
+            if not subscription["status"]["isActive"] != 0:
                 LOGGER.info("Skipping inactive subscription: %s", sid)
                 continue
 
